pycocoa.octypes.ObjC_t

Package pycocoa :: Module octypes :: Class ObjC_t |
[frames] | no frames]

# Class ObjC_t

          object --+
                   |
           ??._CData --+
                       |
    _ctypes._SimpleCData --+
                           |
             ctypes.c_void_p --+
                               |
                              ObjC_t

Known Subclasses:
  - Allocator_t
  - , Block_t
  - , Id_t
  - , IMP_t
  - , Ivar_t
  - , Method_t
  - , printers.PMPaper_t
  - , printers.PMPrinter_t
  - , SEL_t
  - , Struct_t
  - , TypeRef_t
  - , UnknownPtr_t
  - , Unknown_t
  - , VoidPtr_t
  - , objc_property_t
  - , printers.PMServer_t
  - , printers.PM_t

Base type to pretty-print ctypes `c_void_p`.

Instance Methods
__repr__(self) repr(x) |
__str__(self) str(x) |
Inherited from `ctypes.c_void_p`: `from_param` Inherited from `_ctypes._SimpleCData`: `__ctypes_from_outparam__`, `__init__`, `__new__`, `__nonzero__` Inherited from `_CData`: `__hash__`, `__reduce__`, `__setstate__` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| typename Get this instance' Python class name (`str`).
Inherited from `_ctypes._SimpleCData`: `value` Inherited from `object`: `__class__`

Method Details

### __repr__(self) (Representation operator) |
repr(x) Overrides: object.__repr__ (inherited documentation)

### __str__(self) (Informal representation operator) |
str(x) Overrides: object.__str__ (inherited documentation)

Property Details

### typename Get this instance' Python class name (`str`). Get Method: typename(self) - Get this instance' Python class name (`str`). Set Method: Read_Only(inst, value) - Throws an `AttributeError`, always.